//   Copyright 2020 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import QtQuick 2.6
import QtQuick.Controls 2.2
import Esri.display_a_map 1.0

import QtQuick.Shapes 1.12


Item {

    // Create MapQuickView here, and create its Map etc. in C++ code
    MapView {
        id: view
        anchors.fill: parent
        // set focus to enable keyboard navigation
        focus: true
    }

    // Declare the C++ instance which creates the map etc. and supply the view
    Display_a_map {
        id: model
        mapView: view
    }

    // Create window for displaying the route directions
    Rectangle {
        id: directionWindow
        anchors {
            right: parent.right
            top: parent.top
            margins: 5
        }
        radius: 5

        visible: model.directions
        width: Qt.platform.os === "ios" || Qt.platform.os === "android" ? 250 : 350
        height: parent.height / 2
        color: "#FBFBFB"
        clip: true

        ListView {
            id: directionsView
            anchors {
                fill: parent
                margins: 5
            }
            header: Component {
                Text {
                    height: 40
                    text: "Directions:"
                    font.pixelSize: 22
                }
            }

            // set the model to the DirectionManeuverListModel returned from the route
            model: model.directions
            delegate: directionDelegate
        }
    }

    Component {
        id: directionDelegate
        Rectangle {
            id: rect
            width: parent.width
            height: textDirections.height
            color: directionWindow.color

            // separator for directions
            Shape {
                height: 2
                ShapePath {
                    strokeWidth: 1
                    strokeColor: "darkgrey"
                    strokeStyle: ShapePath.SolidLine
                    startX: 20; startY: 0
                    PathLine { x: parent.width - 20 ; y: 0 }
                }
            }

            Text {
                id: textDirections
                text: qsTr("%1 (%2 miles)".arg(directionText).arg((length * 0.00062137).toFixed(2)))
                wrapMode: Text.WordWrap
                anchors {
                    leftMargin: 5
                    left: parent.left
                    right: parent.right
                }
            }
        }
    }

}

